@@ -362,6 +362,7 @@ define!({
         Viewport(ViewportRule),
         Document(DocumentRule),
         ColorProfile(ColorProfileRule),
+        CounterStyle(CounterStyleRule),
         Unknown(UnknownAtRule),
     }
 
@@ -676,4 +677,10 @@ define!({
         pub name: ColorProfileName,
         pub block: Vec<DeclarationBlockItem>,
     }
+
+    pub struct CounterStyleRule {
+        pub span: Span,
+        pub name: CustomIdent,
+        pub block: Vec<DeclarationBlockItem>,
+    }
 });
